function result = correct_boundingbox(Pathname, FileName, correction_value)
% This function modifies the bounding box of an eps file.
% Input:
% Pathname :        Path to the eps file
% FileName :        File name of the eps file
% correction_value: Values to be added to the current bounding box values
%     first 2: lower left corner
%     last  2: upper-right corner
%     unit   : post script points = 1/72 inch
%     [xll yll xur yur]
%     yll = -7 ==> lower bounding box
%     xur = -15 ==> tighter bounding box at the right side
%     e.g. correction_value = [0 -10 -15 -3].';
% (c) by Michael Ruder, LMK December 2010

%% Program
%% Corrects the bounding box

if FileName == 0
  result = false;
else
  source   = [Pathname FileName];
  tempfile = [Pathname FileName(1:end-4) '_new' FileName(end-3:end)];
  fid  = fopen(source);
  fidw = fopen(tempfile, 'w');
  if fid<0
    result = false;
    return;
    %error('Could not open file!');
  end
  tline = fgets(fid);
  while ischar(tline)
    if strncmp('%%BoundingBox:', tline, 14)
      display('Found BoundingBox:');
      display(tline(15:end));
      bb_String = tline(15:end);
      A = sscanf(bb_String, '%d');
      if size(A,1) == 4 % we got 4 different intergers
        A_new = A + correction_value;
        tline = sprintf('%%%%BoundingBox:   %d   %d   %d   %d\r\n', A_new(1), A_new(2), A_new(3), A_new(4));
      end
    end
    fwrite(fidw, tline, 'char');
    tline = fgets(fid);
  end
fclose(fid);
fclose(fidw);
movefile(source, [source '.old']);
movefile(tempfile, source);
result = true;
end