% function preparePlotForExport(graph_type, h_fig, varargin)

% $Id: preparePlotForExport.m 1264 2012-12-04 20:51:53Z mr $
%
% Copyright (c) 2009 Armin C. Schmidt <dunkelschorsch AT googlemail DOT com>
%
% Permission is hereby granted, free of charge, to any person obtaining a copy
% of this software and associated documentation files (the "Software"), to deal
% in the Software without restriction, including without limitation the rights
% to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
% copies of the Software, and to permit persons to whom the Software is
% furnished to do so, subject to the following conditions:
%
% The above copyright notice and this permission notice shall be included in
% all copies or substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
% IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
% FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
% AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
% LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
% OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
% THE SOFTWARE.

function preparePlotForExport(graph_type, h_fig, varargin)

% modify a copy, not the original plot
% h_fig = copyobj(h_fig_in, 0);

fig_children = get(h_fig, 'Children');

h_legend = [];
h_axes = [];

h_legend = fig_children(strcmp(get(fig_children, 'Tag'), 'legend'));
h_axes = fig_children(strcmp(get(fig_children, 'Tag'), ''));

num_subfigs = numel(h_axes);
num_legends = numel(h_legend);

p = inputParser();
p.addOptional('PlotAspectRatio', 4/3, @(x) isnumeric(x) && x>0);
p.addOptional('LegendExtraSpace', '0mm');
p.addOptional('LegendFix', false, @islogical);
p.addOptional('LegendKeepPosition', false, @islogical);
p.addOptional('LegendAspectRatio', [8 5 1], @(x) length(x) == 3);
% Bitstream Charter: -0.8em
% EulerVM: +0.2em
% Computer Modern: +0.4em

isposnumber = @(x) isnumeric(x) && x>=1;

if (strcmp(graph_type, 'beamer'))
    p.addOptional('TitleFontSize',   9, isposnumber);
    p.addOptional('LegendFontSize',  7, isposnumber);
    p.addOptional('TickFontSize',    7, isposnumber);
    p.addOptional('LabelFontSize',   9, isposnumber);
    p.addOptional('PlotSizeX',      12, isposnumber);
elseif (strcmp(graph_type, 'twocolumn'))
    p.addOptional('TitleFontSize',  10, isposnumber);
    p.addOptional('LegendFontSize',  9, isposnumber);
    p.addOptional('TickFontSize',    8, isposnumber);
    p.addOptional('LabelFontSize',  10, isposnumber);
    p.addOptional('PlotSizeX',      12, isposnumber);
else
    error('%s?! Gibts nicht ...\n', graph_type);
end

p.parse(varargin{:});

plotAspectRatio    = p.Results.PlotAspectRatio;
titleFontSize      = p.Results.TitleFontSize;
legendFontSize     = p.Results.LegendFontSize;
tickFontSize       = p.Results.TickFontSize;
labelFontSize      = p.Results.LabelFontSize;
plotSizeX          = p.Results.PlotSizeX;
plotSizeY          = plotSizeX / plotAspectRatio;
legendExtraSpace   = p.Results.LegendExtraSpace;
legendFix          = p.Results.LegendFix;
legendAR           = p.Results.LegendAspectRatio;
legendKeepPosition = p.Results.LegendKeepPosition;

if(~strcmp(get(h_fig, 'Userdata'), 'modified'))
    set(h_fig, 'Userdata', 'modified');
    for legend_curr=1:num_legends
        set(h_legend(legend_curr), 'String', strcat(get(h_legend(legend_curr), 'String'), sprintf('\\hspace{%s}', legendExtraSpace) ) );
    end
end

% set all font sizes
for curr_subplot=1:num_subfigs
    set([get(h_axes(curr_subplot), 'XLabel'), get(h_axes(curr_subplot), 'YLabel'), get(h_axes(curr_subplot), 'ZLabel')], 'FontSize', labelFontSize);
    set(h_axes(curr_subplot), 'FontSize', tickFontSize);
    set(get(h_axes(curr_subplot), 'Title'), 'FontSize', titleFontSize);
end

for curr_subplot=1:num_legends
    set(h_legend(curr_subplot), 'FontSize', legendFontSize);
end

% use the latex interpreter everywhere
set(findobj(h_fig, '-property', 'interpreter'), 'interpreter', 'latex');

if(legendFix)
    % nudge the legend text down a little
    cc=findobj(get(h_legend, 'Children'), '-property', 'Position');
    pos=get(cc, 'Position');
    for i=1:length(cc)
        if(~iscell(pos))
            new_pos = pos - [0 .05 0];
        else
            new_pos = pos{i} - [0 .05 0];
        end
        set(cc(i), 'Position', new_pos);
    end
end

% adjust the figure size
set(h_fig, 'units', 'centimeters');
pos = get(h_fig, 'position');
%set(h_fig, 'position', [ pos(1:2), plotSizeX, plotSizeY ]);

% Change the size of the legend
for curr_subplot=1:num_legends
    leg_pos = get(h_legend(curr_subplot), 'Position');
    set(h_legend(curr_subplot), 'PlotBoxAspectRatioMode', 'manual');
    newAR = legendAR .* [ leg_pos(3:4) 1 ];
    set(h_legend(curr_subplot), 'PlotBoxAspectRatio', newAR);
    
    if(~legendKeepPosition)
        magic_value__ = 1.27; % here be dragons
        % Change the position of the legend
        distance = 0.5 * (leg_pos(4) - (magic_value__ * leg_pos(3) * newAR(2)/newAR(1)));
        % move up or down
        direction = sign((leg_pos(2) + 0.5 * leg_pos(4)) - 0.5);
        set(h_legend(curr_subplot), 'Position', leg_pos + direction * [0 distance 0 0]);
    end
end

end
